summaryrefslogtreecommitdiffstats
path: root/generic/ttk/ttkBlink.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/ttk/ttkBlink.c')
-rw-r--r--generic/ttk/ttkBlink.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/generic/ttk/ttkBlink.c b/generic/ttk/ttkBlink.c
index cc87397..2476fcd 100644
--- a/generic/ttk/ttkBlink.c
+++ b/generic/ttk/ttkBlink.c
@@ -1,16 +1,16 @@
/*
- * $Id: ttkBlink.c,v 1.1 2006/10/31 01:42:26 hobbs Exp $
+ * $Id: ttkBlink.c,v 1.2 2006/11/03 03:06:21 das Exp $
*
* Copyright 2004, Joe English.
*
* Usage:
* BlinkCursor(corePtr), usually called in a widget's Init hook,
* arranges to periodically toggle the corePtr->flags CURSOR_ON bit
* on and off (and schedule a redisplay) whenever the widget has focus.
*
* Note: Widgets may have additional logic to decide whether
* to display the cursor or not (e.g., readonly or disabled states);
* BlinkCursor() does not account for this.
*
* TODO:
* Add script-level access to configure application-wide blink rate.
@@ -155,11 +155,11 @@ CursorEventProc(ClientData clientData, XEvent *eventPtr)
}
/*
- * BlinkCursor (main routine) --
+ * TtkBlinkCursor (main routine) --
* Arrange to blink the cursor on and off whenever the
* widget has focus.
*/
-void BlinkCursor(WidgetCore *corePtr)
+void TtkBlinkCursor(WidgetCore *corePtr)
{
Tk_CreateEventHandler(
corePtr->tkwin, CursorEventMask, CursorEventProc, corePtr);
@@ -1,16 +1,16 @@
*
* Usage:
- * BlinkCursor(corePtr), usually called in a widget's Init hook,
+ * TtkBlinkCursor(corePtr), usually called in a widget's Init hook,
* arranges to periodically toggle the corePtr->flags CURSOR_ON bit
* on and off (and schedule a redisplay) whenever the widget has focus.
@@ -1,16 +1,16 @@
* Note: Widgets may have additional logic to decide whether
* to display the cursor or not (e.g., readonly or disabled states);
- * BlinkCursor() does not account for this.
+ * TtkBlinkCursor() does not account for this.
*
* TODO: